# -*- coding: utf-8 -*-
from django.template import engines

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from tests.test_app.models import DummyLink, DummySpacer

from djangocms_text_ckeditor.cms_plugins import TextPlugin


@plugin_pool.register_plugin
class PreviewDisabledPlugin(CMSPluginBase):
    text_editor_preview = False

    def get_render_template(self, context, instance, placeholder):
        template = '<span>Preview is disabled for this plugin</span>'
        return engines['django'].from_string(template)


@plugin_pool.register_plugin
class SekizaiPlugin(CMSPluginBase):
    name = 'Sekizai'
    render_template = 'test_app/plugin_with_sekizai.html'


@plugin_pool.register_plugin
class ExtendedTextPlugin(TextPlugin):
    name = 'Extended'


@plugin_pool.register_plugin
class DummyLinkPlugin(CMSPluginBase):
    render_plugin = False
    model = DummyLink


@plugin_pool.register_plugin
class DummySpacerPlugin(CMSPluginBase):
    render_plugin = False
    model = DummySpacer



# -*- coding: utf-8 -*-
from distutils.version import LooseVersion
from functools import WRAPPER_ASSIGNMENTS

import cms

import six


cms_version = LooseVersion(cms.__version__)

LTE_CMS_3_3 = cms_version < LooseVersion('3.4')
LTE_CMS_3_4 = cms_version < LooseVersion('3.5')


def get_page_placeholders(page, language=None):
    try:
        # cms3.6 compat
        return page.get_placeholders()
    except TypeError:
        return page.get_placeholders(language)


# this also exists on the latest django CMS release (3.7.2)
# though we want to keep compatibility to older CMS versions
def available_attrs(fn):
    if six.PY3:
        return WRAPPER_ASSIGNMENTS
    else:
        return tuple(a for a in WRAPPER_ASSIGNMENTS if hasattr(fn, a))



# -*- coding: utf-8 -*-
from django.contrib import admin

from .models import Pizza, Topping


class ToppingInlineAdmin(admin.TabularInline):
    model = Topping
    extra = 1


class PizzaAdmin(admin.ModelAdmin):
    fieldsets = (
        ('', {
            'fields': ('description',),
        }),
        ('Advanced', {
            # NOTE: Disabled because when PizzaAdmin uses a collapsed
            # class then the order of javascript libs is incorrect.
            # 'classes': ('collapse',),
            'fields': ('allergens',)
        }),
    )
    inlines = [ToppingInlineAdmin]


admin.site.register(Pizza, PizzaAdmin)
